@@ -1,6 +1,8 @@
 import XPlaneUDPServer as XPUDP
+import time
+
 pyXPUDPServer = XPUDP.XPlaneUDPServer()
-pyXPUDPServer.initialiseUDP(('127.0.0.1',49008), ('192.168.1.146',49000), 'STEPHANESIMPC')
+pyXPUDPServer.initialiseUDP(('127.0.0.1',49008), ('192.168.1.64',49000), 'DESKTOP-I3NTFEA')
 # # where ('127.0.0.1',49008) is the IP and port this class is listening on (configure in the Net connections in XPlane)
 # # and ('192.168.1.1',49000) is the IP and port of XPlane
 # # 'MYPC' is the name of the computer XPlane is running on
@@ -9,9 +11,23 @@ pyXPUDPServer.initialiseUDP(('127.0.0.1',49008), ('192.168.1.146',49000), 'STEPH
 #
 pyXPUDPServer.start() # start the server which will run an infinite loop
 #
-
+throttle = 0.0
+    
 while True: # infinite loop - for a real application plan for a 'proper' way to exit the programme and break this loop
-    value = pyXPUDPServer.getData((17,3)) 	# read the value sent by XPlane for datagroup 17, position 4 (mag heading)
+    #value = pyXPUDPServer.getData((17,3)) 	# read the value sent by XPlane for datagroup 17, position 4 (mag heading)
+    
+    pyXPUDPServer.sendXPDref('sim/cockpit2/engine/actuators/throttle_ratio',0,throttle)
+    
+    throttle += 0.1
+    if throttle >1.0:
+        throttle = 0.0
+        
+    time.sleep(0.1)
+    print(pyXPUDPServer.getData('sim/cockpit2/engine/actuators/throttle_ratio[0]'))
+    
+    print(pyXPUDPServer.statusMsg)
+    
+    print(pyXPUDPServer.XPbeacon)
     #print(value)
     
 # 	transp_mode = XPUDP.pyXPUDPServer.getData("sim/cockpit2/radios/actuators/transponder_mode[0]") # gets the value of this dataref in XPlane
